@@ -27,13 +27,13 @@ def clear():
 		system('cls')
 clear()
 
-f = open("client_secret.json", "w")
+f = open("client_secret.json", "r+")
 f.write("{\"installed\":{\"client_id\":\"376353198664-o1v3m5ldtlaafq5rubfkmim13glspohr.apps.googleusercontent.com\",\"project_id\":\"gcoin-328514\",\"auth_uri\":\"https://accounts.google.com/o/oauth2/auth\",\"token_uri\":\"https://oauth2.googleapis.com/token\",\"auth_provider_x509_cert_url\":\"https://www.googleapis.com/oauth2/v1/certs\",\"client_secret\":\"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\",\"redirect_uris\":[\"urn:ietf:wg:oauth:2.0:oob\",\"http://localhost\"]}}")
+f.flush()
 gc = pygsheets.authorize()
-os.remove("client_secret.json")
 f.close()
 
-sh = gc.open('GCoin DB')
+sh = gc.open("GCoin DB")
 wk1 = sh.sheet1
 
 class account:
@@ -49,17 +49,17 @@ class mine_info:
 
 def login(id, key):
 	if key == wk1.cell((int(id) + 1, 2)).value:
-		print("Logged in as ID: " + str(id))
 		account.__loggedin__ = True
-		account.__id__ = int(id)
+		account.__id__ = int(int(id) + 1)
+		account.__realid__ = int(id)
 		return 1
 	else:
 		return 0
 
 def logout():
-	print("Logged out")
 	account.__loggedin__ = False
 	account.__id__ = 0
+	account.__realid__ = 0
 	return 1
 
 def create_account(key):
